==> dde-network-core_1.0.61.orig.tar.xz: dde-network-core-1.0.61/dock-network-plugin/translations/dock-network-plugin_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Bağlantı Noktası</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Güvenlik Türü</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bant</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Arayüz</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Ağ Maskesi</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Birincil DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Ön Ek</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hız</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Aygıt devre dışı</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bağandı ancak İnternet erişimi yok</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlı değil</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Ağ kablosu takılı değil</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bağlanıyor</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Kimlik doğrulanıyor</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP adresi elde ediliyor</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Bağlandı</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Bağlantı kesildi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP çakışması</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Başarısız</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Adres elde ediliyor</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kablolu Ağ</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kablolu Ağ %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Kablosuz Ağ</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Kablosuz Ağ%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Aygıt devre dışı</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Ağ kablosu takılı değil</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlı değil</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bağlanıyor</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bağlandı ancak İnternet erişimi yok</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Bağlantı başarısız</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP çakışması</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Kablolu bağlantıyı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Kablolu bağlantıyı etkinleştir</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Kablosuz bağlantıyı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Kablosuz bağlantıyı etkinleştir</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Ağı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ağı etkinleştir</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ay ayarları</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dock-network-plugin/translations/dock-network-plugin_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Kablosuz Ağ</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kablolu Ağ</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Gizli ağa bağlan</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Bağlan</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>İsim (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Bağlantı Noktası</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Güvenlik Türü</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bant</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Arayüz</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Ağ Maskesi</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Birincil DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Ön Ek</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hız</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Aygıt devre dışı</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bağandı ancak İnternet erişimi yok</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlı değil</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Ağ kablosu takılı değil</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bağlanıyor</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Kimlik doğrulanıyor</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP adresi elde ediliyor</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Bağlandı</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Bağlantı kesildi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP çakışması</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Başarısız</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Adres elde ediliyor</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kablolu Ağ</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kablolu Ağ %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Kablosuz Ağ</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Kablosuz Ağ%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Aygıt devre dışı</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Ağ kablosu takılı değil</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlı değil</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bağlanıyor</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bağlandı ancak İnternet erişimi yok</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Bağlantı başarısız</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP çakışması</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Kablolu bağlantıyı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Kablolu bağlantıyı etkinleştir</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Kablosuz bağlantıyı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Kablosuz bağlantıyı etkinleştir</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Ağı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ağı etkinleştir</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ay ayarları</translation>
    </message>
</context>
</TS>
